@@ -7,6 +7,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 
 #include "clock.h"
 #include "clock-face.h"
@@ -180,7 +181,7 @@ make_current_cb (gpointer data, GError *error)
                                                  GTK_MESSAGE_ERROR,
                                                  GTK_BUTTONS_OK,
                                                  _("Failed to set the system timezone"));
-                gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message);
+                gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
                 g_signal_connect (dialog, "response",
                                   G_CALLBACK (gtk_widget_destroy), NULL);
                 gtk_window_present (GTK_WINDOW (dialog));
@@ -193,8 +194,17 @@ static void
 make_current (GtkWidget *widget, ClockLocationTile *tile)
 {
         ClockLocationTilePrivate *priv = PRIVATE (tile);
+	GtkWidget *toplevel;
+	guint xid;
 
-	clock_location_make_current (priv->location, 
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tile));
+	if (toplevel && toplevel->window)
+		xid = GDK_WINDOW_XWINDOW (toplevel->window);
+	else
+		xid = 0;
+
+	clock_location_make_current (priv->location,
+				     xid,
 				     (GFunc)make_current_cb, tile, NULL);
 }
 
@@ -303,8 +313,8 @@ clock_location_tile_fill (ClockLocationTile *this)
         gtk_widget_show (priv->current_label);
         gtk_widget_set_no_show_all (priv->current_button, TRUE);
         gtk_container_add (GTK_CONTAINER (priv->current_button), priv->current_label);
-	/* FIXME: this needs to talk about locations, not timezones */
-        gtk_widget_set_tooltip_text (priv->current_button, _("Set as current timezone for this computer"));
+        gtk_widget_set_tooltip_text (priv->current_button,
+				     _("Set location as current location and use its timezone for this computer"));
 
 	priv->current_marker = gtk_image_new_from_icon_name ("go-home", GTK_ICON_SIZE_BUTTON);
 	gtk_misc_set_alignment (GTK_MISC (priv->current_marker), 1.0, 0.5);
@@ -354,8 +364,6 @@ clock_location_tile_fill (ClockLocationTile *this)
         gtk_container_add (GTK_CONTAINER (alignment), tile);
         gtk_container_add (GTK_CONTAINER (priv->box), alignment);
         gtk_container_add (GTK_CONTAINER (this), priv->box);
-
-        clock_location_tile_refresh (this, TRUE);
 }
 
 static gboolean
