@@ -27,83 +27,74 @@
 
 #include "obox.h"
 
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
 
-static void tray_obox_class_init    (TrayOBoxClass   *klass);
-static void tray_obox_init          (TrayOBox        *box);
-static void tray_obox_size_request  (GtkWidget       *widget,
-				     GtkRequisition  *requisition);
-static void tray_obox_size_allocate (GtkWidget       *widget,
-				     GtkAllocation   *allocation);
+static void na_obox_size_request  (GtkWidget       *widget,
+				   GtkRequisition  *requisition);
+static void na_obox_size_allocate (GtkWidget       *widget,
+				   GtkAllocation   *allocation);
 
 
-GType
-tray_obox_get_type (void)
+G_DEFINE_TYPE (NaOBox, na_obox, GTK_TYPE_BOX)
+
+static void
+na_obox_finalize (GObject *object)
 {
-  static GType obox_type = 0;
+  NaOBox *obox;
 
-  if (!obox_type)
-    {
-      static const GTypeInfo obox_info =
-      {
-        sizeof (TrayOBoxClass),
-        (GBaseInitFunc)         NULL,
-        (GBaseFinalizeFunc)     NULL,
-        (GClassInitFunc)        tray_obox_class_init,
-        NULL,                   /* class_finalize */
-        NULL,                   /* class_data */
-        sizeof (TrayOBox),
-        0,                      /* n_preallocs */
-        (GInstanceInitFunc)     tray_obox_init 
-      };
+  obox = NA_OBOX (object);
 
-      obox_type = g_type_register_static (GTK_TYPE_BOX, "TrayOBox",
-                                          &obox_info, 0);
-    }
+  g_type_class_unref (obox->hbox_type);
+  g_type_class_unref (obox->vbox_type);
 
-  return obox_type;
+  G_OBJECT_CLASS (na_obox_parent_class)->finalize (object);
 }
 
 static void
-tray_obox_class_init (TrayOBoxClass *class)
+na_obox_class_init (NaOBoxClass *class)
 {
+  GObjectClass   *gobject_class;
   GtkWidgetClass *widget_class;
 
+  gobject_class = (GObjectClass*) class;
   widget_class = (GtkWidgetClass*) class;
 
-  widget_class->size_request = tray_obox_size_request;
-  widget_class->size_allocate = tray_obox_size_allocate;
+  gobject_class->finalize = na_obox_finalize;
+  widget_class->size_request = na_obox_size_request;
+  widget_class->size_allocate = na_obox_size_allocate;
 }
 
 static void
-tray_obox_init (TrayOBox *obox)
+na_obox_init (NaOBox *obox)
 {
   obox->orientation = GTK_ORIENTATION_HORIZONTAL;
+
+  obox->hbox_type = g_type_class_ref (GTK_TYPE_HBOX);
+  obox->vbox_type = g_type_class_ref (GTK_TYPE_VBOX);
 }
 
 GtkWidget*
-tray_obox_new (void)
+na_obox_new (void)
 {
-  TrayOBox *obox;
+  NaOBox *obox;
 
-  obox = g_object_new (TRAY_TYPE_OBOX, NULL);
+  obox = g_object_new (NA_TYPE_OBOX, NULL);
 
   return GTK_WIDGET (obox);
 }
 
 static GtkWidgetClass*
-get_class (TrayOBox *obox)     
+get_class (NaOBox *obox)     
 {
   GtkWidgetClass *klass;
 
   switch (obox->orientation)
     {
     case GTK_ORIENTATION_HORIZONTAL:
-      klass = GTK_WIDGET_CLASS (gtk_type_class (GTK_TYPE_HBOX));
+      klass = GTK_WIDGET_CLASS (obox->hbox_type);
       break;
     case GTK_ORIENTATION_VERTICAL:
-      klass = GTK_WIDGET_CLASS (gtk_type_class (GTK_TYPE_VBOX));
+      klass = GTK_WIDGET_CLASS (obox->vbox_type);
       break;
     default:
       g_assert_not_reached ();
@@ -115,13 +106,13 @@ get_class (TrayOBox *obox)
 }
 
 static void
-tray_obox_size_request (GtkWidget      *widget,
-		        GtkRequisition *requisition)
+na_obox_size_request (GtkWidget      *widget,
+		      GtkRequisition *requisition)
 {
   GtkWidgetClass *klass;
-  TrayOBox *obox;
+  NaOBox *obox;
 
-  obox = TRAY_OBOX (widget);
+  obox = NA_OBOX (widget);
 
   klass = get_class (obox);
 
@@ -129,13 +120,13 @@ tray_obox_size_request (GtkWidget      *widget,
 }
 
 static void
-tray_obox_size_allocate (GtkWidget     *widget,
-			 GtkAllocation *allocation)
+na_obox_size_allocate (GtkWidget     *widget,
+		       GtkAllocation *allocation)
 {
   GtkWidgetClass *klass;
-  TrayOBox *obox;
+  NaOBox *obox;
 
-  obox = TRAY_OBOX (widget);
+  obox = NA_OBOX (widget);
 
   klass = get_class (obox);
 
@@ -143,10 +134,10 @@ tray_obox_size_allocate (GtkWidget     *widget,
 }
 
 void
-tray_obox_set_orientation (TrayOBox       *obox,
-                           GtkOrientation  orientation)
+na_obox_set_orientation (NaOBox         *obox,
+                         GtkOrientation  orientation)
 {
-  g_return_if_fail (TRAY_IS_OBOX (obox));
+  g_return_if_fail (NA_IS_OBOX (obox));
 
   if (obox->orientation == orientation)
     return;
